@@ -25,22 +25,17 @@ impl PublicKeySet {
         reader: &mut impl Read,
         detached_signature: Option<&[u8]>,
         predicates: &[impl Fn(&Section) -> bool],
-    ) -> Result<Vec<HashSet<PublicKey>>, WSError> {
+    ) -> Result<Vec<HashSet<&PublicKey>>, WSError> {
         let mut sections = Module::stream(reader)?;
-        let signature_header: &Section;
-        let signature_header_from_detached_signature;
-        let signature_header_from_stream;
-        if let Some(detached_signature) = &detached_signature {
-            signature_header_from_detached_signature = Section::Custom(CustomSection::new(
+        let signature_header_section = if let Some(detached_signature) = &detached_signature {
+            Section::Custom(CustomSection::new(
                 SIGNATURE_SECTION_HEADER_NAME.to_string(),
                 detached_signature.to_vec(),
-            ));
-            signature_header = &signature_header_from_detached_signature;
+            ))
         } else {
-            signature_header_from_stream = sections.next().ok_or(WSError::ParseError)??;
-            signature_header = &signature_header_from_stream;
-        }
-        let signature_header = match signature_header {
+            sections.next().ok_or(WSError::ParseError)??
+        };
+        let signature_header = match signature_header_section {
             Section::Custom(custom_section) if custom_section.is_signature_header() => {
                 custom_section
             }
@@ -49,6 +44,7 @@ impl PublicKeySet {
                 return Err(WSError::NoSignatures);
             }
         };
+
         let signature_data = signature_header.signature_data()?;
         if signature_data.hash_function != SIGNATURE_HASH_FUNCTION {
             debug!(
@@ -57,8 +53,8 @@ impl PublicKeySet {
             );
             return Err(WSError::ParseError);
         }
-        let signed_hashes_set = signature_data.signed_hashes_set;
 
+        let signed_hashes_set = signature_data.signed_hashes_set;
         let mut valid_hashes_for_pks = HashMap::new();
         for pk in &self.pks {
             let valid_hashes = pk.valid_hashes_for_pk(&signed_hashes_set)?;
@@ -125,15 +121,15 @@ impl PublicKeySet {
             }
         }
 
-        let mut res: Vec<HashSet<PublicKey>> = vec![];
+        let mut res: Vec<HashSet<&PublicKey>> = vec![];
         for _predicate in predicates {
-            let mut result_for_predicate: HashSet<PublicKey> = HashSet::new();
+            let mut result_for_predicate: HashSet<&PublicKey> = HashSet::new();
             for pk in &self.pks {
                 if !valid_hashes_for_pks.contains_key(pk) {
                     continue;
                 }
                 if !verify_failures_for_predicates[res.len()].contains(pk) {
-                    result_for_predicate.insert(pk.clone());
+                    result_for_predicate.insert(pk);
                 }
             }
             res.push(result_for_predicate);
