@@ -173,20 +173,15 @@ impl PublicKey {
         P: FnMut(&Section) -> bool,
     {
         let mut sections = Module::stream(reader)?.enumerate();
-        let signature_header: &Section;
-        let signature_header_from_detached_signature;
-        let signature_header_from_stream;
-        if let Some(detached_signature) = &detached_signature {
-            signature_header_from_detached_signature = Section::Custom(CustomSection::new(
+        let signature_header_section = if let Some(detached_signature) = &detached_signature {
+            Section::Custom(CustomSection::new(
                 SIGNATURE_SECTION_HEADER_NAME.to_string(),
                 detached_signature.to_vec(),
-            ));
-            signature_header = &signature_header_from_detached_signature;
+            ))
         } else {
-            signature_header_from_stream = sections.next().ok_or(WSError::ParseError)?.1?;
-            signature_header = &signature_header_from_stream;
-        }
-        let signature_header = match signature_header {
+            sections.next().ok_or(WSError::ParseError)?.1?
+        };
+        let signature_header = match signature_header_section {
             Section::Custom(custom_section) if custom_section.is_signature_header() => {
                 custom_section
             }
@@ -195,6 +190,7 @@ impl PublicKey {
                 return Err(WSError::NoSignatures);
             }
         };
+
         let signature_data = signature_header.signature_data()?;
         if signature_data.hash_function != SIGNATURE_HASH_FUNCTION {
             debug!(
@@ -203,6 +199,7 @@ impl PublicKey {
             );
             return Err(WSError::ParseError);
         }
+
         let signed_hashes_set = signature_data.signed_hashes_set;
         let valid_hashes = self.valid_hashes_for_pk(&signed_hashes_set)?;
         if valid_hashes.is_empty() {
